@@ -15,20 +15,25 @@
 
 # Import APIs into API package:
 from delphix.api.gateway.api.accounts_api import AccountsApi
-from delphix.api.gateway.api.api_clients_api import ApiClientsApi
 from delphix.api.gateway.api.authorization_api import AuthorizationApi
 from delphix.api.gateway.api.bookmarks_api import BookmarksApi
+from delphix.api.gateway.api.cdbs_api import CDBsApi
 from delphix.api.gateway.api.connectivity_api import ConnectivityApi
 from delphix.api.gateway.api.connectors_api import ConnectorsApi
 from delphix.api.gateway.api.d_sources_api import DSourcesApi
+from delphix.api.gateway.api.database_templates_api import DatabaseTemplatesApi
 from delphix.api.gateway.api.environments_api import EnvironmentsApi
+from delphix.api.gateway.api.executions_api import ExecutionsApi
 from delphix.api.gateway.api.jobs_api import JobsApi
 from delphix.api.gateway.api.login_api import LoginApi
 from delphix.api.gateway.api.management_api import ManagementApi
-from delphix.api.gateway.api.masking_job_sets_api import MaskingJobSetsApi
+from delphix.api.gateway.api.masking_jobs_api import MaskingJobsApi
 from delphix.api.gateway.api.reporting_api import ReportingApi
+from delphix.api.gateway.api.saml_login_api import SamlLoginApi
 from delphix.api.gateway.api.snapshots_api import SnapshotsApi
 from delphix.api.gateway.api.sources_api import SourcesApi
 from delphix.api.gateway.api.test_api import TestApi
+from delphix.api.gateway.api.timeflows_api import TimeflowsApi
+from delphix.api.gateway.api.vcdbs_api import VCDBsApi
 from delphix.api.gateway.api.vdb_groups_api import VDBGroupsApi
 from delphix.api.gateway.api.vdbs_api import VDBsApi
